@@ -82,7 +82,7 @@ class CollectionMenuBars:
     quit_menu: tk.Menu
 
 
-class MainWindow(tk.Tk, LoggerMixin):  # pylint: disable=too-many-instance-attributes
+class MainWindow(tk.Tk, LoggerMixin):
     """Represents the main window of an application.
 
     In an Tkinter application, the instance of the Tk class represents the main window.
@@ -119,7 +119,7 @@ class MainWindow(tk.Tk, LoggerMixin):  # pylint: disable=too-many-instance-attri
         """Handles the SIGINT generated by an user when hitting Ctrl+C in the shell."""
         self.stop_application()
 
-    def _determine_script_path(self):  # pylint: disable=no-self-use
+    def _determine_script_path(self):
         running_script = inspect.getframeinfo(inspect.currentframe()).filename  # /powermolegui/lib/windows.py
         running_script_dir = os.path.dirname(os.path.abspath(running_script))
         return os.path.dirname(running_script_dir)  # /powermolegui
@@ -234,7 +234,7 @@ class MainWindow(tk.Tk, LoggerMixin):  # pylint: disable=too-many-instance-attri
         """Retrieves the recently opened configuration file stored in /settings."""
         path_file_recent = os.path.join(self._script_path, 'settings', 'recently_opened_config_file')
         try:
-            with open(path_file_recent) as file:
+            with open(path_file_recent, encoding='utf-8') as file:
                 self._path_config_file = file.read().rstrip()
         except FileNotFoundError:
             pass
@@ -244,7 +244,7 @@ class MainWindow(tk.Tk, LoggerMixin):  # pylint: disable=too-many-instance-attri
     def _write_to_recently_opened(self, path_config_file):
         """Stores the location to the recently opened configuration file."""
         path_file_recent = os.path.join(self._script_path, 'settings', 'recently_opened_config_file')
-        with open(path_file_recent, 'w') as file:
+        with open(path_file_recent, 'w', encoding='utf-8') as file:
             file.write(path_config_file)
 
     def config_file_dialog(self):
@@ -336,7 +336,8 @@ class CommandWindow(tk.Toplevel):
         win_height = WINDOW_HEIGHT * 0.7  # height of the main window
         start_x = (screen_width / 2) - (win_width / 2)
         start_y = (screen_height / 2) - (win_height / 2)
-        self.geometry('%dx%d+%d+%d' % (win_width, win_height, start_x, start_y))  # geometry behaves erratic!
+        # self.geometry('%dx%d+%d+%d' % (win_width, win_height, start_x, start_y))  # geometry behaves erratic!
+        self.geometry(f'{win_width}x{win_height}+{start_x}+{start_y}')  # geometry behaves erratic!
         self.resizable(True, True)
 
     def close_window(self):
@@ -381,5 +382,6 @@ class TransferWindow(tk.Toplevel):
         win_height = WINDOW_HEIGHT * 0.7  # height of the main window
         start_x = (screen_width / 2) - (win_width / 2)
         start_y = (screen_height / 2) - (win_height / 2)
-        self.geometry('%dx%d+%d+%d' % (win_width, win_height, start_x, start_y))  # geometry behaves erratic!
+        # self.geometry('%dx%d+%d+%d' % (win_width, win_height, start_x, start_y))  # geometry behaves erratic!
+        self.geometry(f'{win_width}x{win_height}+{start_x}+{start_y}')  # geometry behaves erratic!
         self.resizable(True, True)
